.onAttach <- function(libname, pkgname){
  packageStartupMessage("********************************************************************************")
  packageStartupMessage("                        Welcome to the package 'quarks'!")
  packageStartupMessage("********************************************************************************")
  packageStartupMessage("")
  packageStartupMessage("Please report any possible errors and bugs to sebastian.let@t-online.de.")
  packageStartupMessage("")
  packageStartupMessage("                              Thank you.")
  packageStartupMessage("")
  packageStartupMessage("********************************************************************************")
}
